const { merge } = require('webpack-merge');
const ip = require('ip');
const FriendlyErrorsPlugin = require('@soda/friendly-errors-webpack-plugin');
const { getProjectPath } = require('../common/utils');
const baseConfig = require('./webpack.base');

const HOST = process.env.HOST || ip.address() || 'localhost';

module.exports = function (appConfig, extendEnv) {
  return merge(baseConfig(false, appConfig, extendEnv), {
    entry: getProjectPath('/src/index.tsx'),
    output: {
      publicPath: '/',
      path: getProjectPath('/dist'),
      pathinfo: true,
      filename: '[name].js',
      chunkFilename: '[name].chunk.js'
    },
    plugins: [
      // 相关配置文档：https://github.com/geowarin/friendly-errors-webpack-plugin
      new FriendlyErrorsPlugin({
        compilationSuccessInfo: {
          messages: [
            `localhost运行链接: http://localhost:${appConfig.port}${appConfig.startOpenPath}\n`,
            `ip运行链接: http://${HOST}:${appConfig.port}${appConfig.startOpenPath}\n`
          ]
        },
        onErrors: null,
        clearConsole: true
      })
    ],
    optimization: {
      minimize: false,
      splitChunks: {
        chunks: 'all',
        name: false
      },
      runtimeChunk: true
    }
  });
};
